@@ -23,7 +23,6 @@
 
 #include <config.h>
 
-#include <check.h>
 #include <libinput.h>
 
 #include "libinput-util.h"
@@ -95,7 +94,7 @@ START_TEST(quirks_invalid_dir)
 				    log_handler,
 				    NULL,
 				    QLOG_LIBINPUT_LOGGING);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 }
 END_TEST
 
@@ -109,7 +108,7 @@ START_TEST(quirks_empty_dir)
 				    log_handler,
 				    NULL,
 				    QLOG_LIBINPUT_LOGGING);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 
 	cleanup_data_dir(dd);
 }
@@ -126,7 +125,7 @@ START_TEST(quirks_section_empty)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -142,7 +141,7 @@ START_TEST(quirks_section_double)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -160,7 +159,7 @@ START_TEST(quirks_section_missing_match)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -178,7 +177,7 @@ START_TEST(quirks_section_missing_attr)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -198,7 +197,7 @@ START_TEST(quirks_section_match_after_attr)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -218,7 +217,7 @@ START_TEST(quirks_section_duplicate_match)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -240,7 +239,7 @@ START_TEST(quirks_section_duplicate_attr)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -260,7 +259,7 @@ START_TEST(quirks_parse_error_section)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -279,7 +278,7 @@ START_TEST(quirks_parse_error_trailing_whitespace)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -298,7 +297,7 @@ START_TEST(quirks_parse_error_unknown_match)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -317,7 +316,7 @@ START_TEST(quirks_parse_error_unknown_attr)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -336,7 +335,7 @@ START_TEST(quirks_parse_error_unknown_model)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -355,7 +354,7 @@ START_TEST(quirks_parse_error_unknown_prefix)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -374,7 +373,7 @@ START_TEST(quirks_parse_error_model_not_one)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -393,7 +392,7 @@ START_TEST(quirks_parse_comment_inline)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -415,7 +414,7 @@ START_TEST(quirks_parse_comment_empty)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -435,7 +434,7 @@ START_TEST(quirks_parse_string_quotes_single)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -455,7 +454,7 @@ START_TEST(quirks_parse_string_quotes_double)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -491,7 +490,7 @@ START_TEST(quirks_parse_bustype)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -511,7 +510,7 @@ START_TEST(quirks_parse_bustype_invalid)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert(ctx == NULL);
+	litest_assert(ctx == NULL);
 	cleanup_data_dir(dd);
 }
 END_TEST
@@ -538,7 +537,7 @@ START_TEST(quirks_parse_vendor)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -570,7 +569,7 @@ START_TEST(quirks_parse_vendor_invalid)
 					    log_handler,
 					    NULL,
 					    QLOG_CUSTOM_LOG_PRIORITIES);
-		ck_assert(ctx == NULL);
+		litest_assert(ctx == NULL);
 		cleanup_data_dir(dd);
 	}
 }
@@ -581,11 +580,11 @@ START_TEST(quirks_parse_product)
 	struct quirks_context *ctx;
 	const char quirks_file[] =
 	"[Section name]\n"
-	"MatchProduct=0x0000\n"
+	"MatchProduct=0x12AB\n"
 	"ModelAppleTouchpad=1\n"
 	"\n"
 	"[Section name]\n"
-	"MatchProduct=0x0001\n"
+	"MatchProduct=0x0001;0x1234;0xABCD\n"
 	"ModelAppleTouchpad=1\n"
 	"\n"
 	"[Section name]\n"
@@ -598,12 +597,54 @@ START_TEST(quirks_parse_product)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
 END_TEST
 
+START_TEST(quirks_parse_product_too_many)
+{
+	struct quirks_context *ctx;
+	const char prologue[] =
+	"[Section name]\n"
+	"MatchProduct=0x12AB\n"
+	"ModelAppleTouchpad=1\n"
+	"\n"
+	"[Section name]\n"
+	"MatchProduct=";
+	const char epilogue[] = "\n"
+	"ModelAppleTouchpad=1\n"
+	"\n"
+	"[Section name]\n"
+	"MatchProduct=0x2343\n"
+	"ModelAppleTouchpad=1\n";
+
+	char matches[4096] = {0};
+
+	for (int i = 0; i < 128; i++) {
+		int len = strlen(matches);
+		int remaining = sizeof(matches) - len;
+		snprintf(&matches[len], remaining, "0x%04X", i);
+	}
+
+	char *quirks_file = NULL;
+	xasprintf(&quirks_file, "%s%s%s", prologue, matches, epilogue);
+	struct data_dir dd = make_data_dir(quirks_file);
+
+	free(quirks_file);
+
+	/* This test will only blow up in valgrind/asan */
+	ctx = quirks_init_subsystem(dd.dirname,
+				    NULL,
+				    log_handler,
+				    NULL,
+				    QLOG_CUSTOM_LOG_PRIORITIES);
+	litest_assert(ctx == NULL);
+	cleanup_data_dir(dd);
+}
+END_TEST
+
 START_TEST(quirks_parse_product_invalid)
 {
 	struct quirks_context *ctx;
@@ -630,7 +671,7 @@ START_TEST(quirks_parse_product_invalid)
 					    log_handler,
 					    NULL,
 					    QLOG_CUSTOM_LOG_PRIORITIES);
-		ck_assert(ctx == NULL);
+		litest_assert(ctx == NULL);
 		cleanup_data_dir(dd);
 	}
 }
@@ -658,7 +699,7 @@ START_TEST(quirks_parse_version)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -690,7 +731,7 @@ START_TEST(quirks_parse_version_invalid)
 					    log_handler,
 					    NULL,
 					    QLOG_CUSTOM_LOG_PRIORITIES);
-		ck_assert(ctx == NULL);
+		litest_assert(ctx == NULL);
 		cleanup_data_dir(dd);
 	}
 }
@@ -730,7 +771,7 @@ START_TEST(quirks_parse_name)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -753,7 +794,7 @@ START_TEST(quirks_parse_name_invalid)
 					    log_handler,
 					    NULL,
 					    QLOG_CUSTOM_LOG_PRIORITIES);
-		ck_assert(ctx == NULL);
+		litest_assert(ctx == NULL);
 		cleanup_data_dir(dd);
 	}
 }
@@ -793,7 +834,7 @@ START_TEST(quirks_parse_uniq)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -816,7 +857,7 @@ START_TEST(quirks_parse_uniq_invalid)
 					    log_handler,
 					    NULL,
 					    QLOG_CUSTOM_LOG_PRIORITIES);
-		ck_assert(ctx == NULL);
+		litest_assert(ctx == NULL);
 		cleanup_data_dir(dd);
 	}
 }
@@ -860,7 +901,7 @@ START_TEST(quirks_parse_udev)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -889,7 +930,7 @@ START_TEST(quirks_parse_udev_invalid)
 					    log_handler,
 					    NULL,
 					    QLOG_CUSTOM_LOG_PRIORITIES);
-		ck_assert(ctx == NULL);
+		litest_assert(ctx == NULL);
 		cleanup_data_dir(dd);
 	}
 }
@@ -913,7 +954,7 @@ START_TEST(quirks_parse_dmi)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	quirks_context_unref(ctx);
 	cleanup_data_dir(dd);
 }
@@ -945,7 +986,7 @@ START_TEST(quirks_parse_dmi_invalid)
 					    log_handler,
 					    NULL,
 					    QLOG_CUSTOM_LOG_PRIORITIES);
-		ck_assert(ctx == NULL);
+		litest_assert(ctx == NULL);
 		cleanup_data_dir(dd);
 	}
 }
@@ -994,9 +1035,9 @@ test_attr_parse(struct litest_device *dev,
 	if (ctx != NULL) {
 		struct quirks *q;
 		q = quirks_fetch_for_device(ctx, ud);
-		ck_assert_notnull(q);
-		ck_assert(func(q, which, data));
-		ck_assert(quirks_has_quirk(q, which));
+		litest_assert_notnull(q);
+		litest_assert(func(q, which, data));
+		litest_assert(quirks_has_quirk(q, which));
 		quirks_unref(q);
 		quirks_context_unref(ctx);
 		result = true;
@@ -1012,7 +1053,7 @@ test_attr_parse(struct litest_device *dev,
 struct qtest_dim {
 		const char *str;
 		bool success;
-		int w, h;
+		size_t w, h;
 };
 
 START_TEST(quirks_parse_dimension_attr)
@@ -1042,12 +1083,12 @@ START_TEST(quirks_parse_dimension_attr)
 					     t->str,
 					     (qparsefunc)quirks_get_dimensions,
 					     &dim);
-			ck_assert_int_eq(rc, t->success);
+			litest_assert_int_eq(rc, t->success);
 			if (!rc)
 				continue;
 
-			ck_assert_int_eq(dim.x, t->w);
-			ck_assert_int_eq(dim.y, t->h);
+			litest_assert_int_eq(dim.x, t->w);
+			litest_assert_int_eq(dim.y, t->h);
 		}
 	}
 }
@@ -1094,12 +1135,12 @@ START_TEST(quirks_parse_range_attr)
 					     t->str,
 					     (qparsefunc)quirks_get_range,
 					     &r);
-			ck_assert_int_eq(rc, t->success);
+			litest_assert_int_eq(rc, t->success);
 			if (!rc)
 				continue;
 
-			ck_assert_int_eq(r.lower, t->lo);
-			ck_assert_int_eq(r.upper, t->hi);
+			litest_assert_int_eq(r.lower, t->lo);
+			litest_assert_int_eq(r.upper, t->hi);
 		}
 	}
 }
@@ -1141,11 +1182,11 @@ START_TEST(quirks_parse_uint_attr)
 					     t->str,
 					     (qparsefunc)quirks_get_uint32,
 					     &v);
-			ck_assert_int_eq(rc, t->success);
+			litest_assert_int_eq(rc, t->success);
 			if (!rc)
 				continue;
 
-			ck_assert_int_eq(v, t->val);
+			litest_assert_int_eq(v, t->val);
 		}
 	}
 }
@@ -1193,11 +1234,11 @@ START_TEST(quirks_parse_double_attr)
 					     t->str,
 					     (qparsefunc)quirks_get_double,
 					     &v);
-			ck_assert_int_eq(rc, t->success);
+			litest_assert_int_eq(rc, t->success);
 			if (!rc)
 				continue;
 
-			ck_assert_int_eq(v, t->val);
+			litest_assert_double_eq(v, t->val);
 		}
 	}
 }
@@ -1245,9 +1286,9 @@ START_TEST(quirks_parse_string_attr)
 					     (qparsefunc)quirks_get_string,
 					     &do_not_use);
 			if (*a == t->where)
-				ck_assert_int_eq(rc, true);
+				litest_assert_int_eq(rc, true);
 			else
-				ck_assert_int_eq(rc, false);
+				litest_assert_int_eq(rc, false);
 		}
 	}
 }
@@ -1284,11 +1325,11 @@ START_TEST(quirks_parse_bool_attr)
 					     t->str,
 					     (qparsefunc)quirks_get_bool,
 					     &v);
-			ck_assert(rc == t->success);
+			litest_assert(rc == t->success);
 			if (!rc)
 				continue;
 
-			ck_assert(v == t->val);
+			litest_assert(v == t->val);
 		}
 	}
 }
@@ -1305,25 +1346,25 @@ START_TEST(quirks_parse_integration_attr)
 			     "internal",
 			     (qparsefunc)quirks_get_string,
 			     &do_not_use);
-	ck_assert(rc);
+	litest_assert(rc);
 	rc = test_attr_parse(dev,
 			     QUIRK_ATTR_KEYBOARD_INTEGRATION,
 			     "external",
 			     (qparsefunc)quirks_get_string,
 			     &do_not_use);
-	ck_assert(rc);
+	litest_assert(rc);
 	rc = test_attr_parse(dev,
 			     QUIRK_ATTR_TRACKPOINT_INTEGRATION,
 			     "internal",
 			     (qparsefunc)quirks_get_string,
 			     &do_not_use);
-	ck_assert(rc);
+	litest_assert(rc);
 	rc = test_attr_parse(dev,
 			     QUIRK_ATTR_TRACKPOINT_INTEGRATION,
 			     "external",
 			     (qparsefunc)quirks_get_string,
 			     &do_not_use);
-	ck_assert(rc);
+	litest_assert(rc);
 }
 END_TEST
 
@@ -1345,13 +1386,13 @@ START_TEST(quirks_model_one)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 
 	q = quirks_fetch_for_device(ctx, ud);
-	ck_assert_notnull(q);
+	litest_assert_notnull(q);
 
-	ck_assert(quirks_get_bool(q, QUIRK_MODEL_APPLE_TOUCHPAD, &isset));
-	ck_assert(isset == true);
+	litest_assert(quirks_get_bool(q, QUIRK_MODEL_APPLE_TOUCHPAD, &isset));
+	litest_assert(isset == true);
 
 	quirks_unref(q);
 	quirks_context_unref(ctx);
@@ -1378,13 +1419,13 @@ START_TEST(quirks_model_zero)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 
 	q = quirks_fetch_for_device(ctx, ud);
-	ck_assert_notnull(q);
+	litest_assert_notnull(q);
 
-	ck_assert(quirks_get_bool(q, QUIRK_MODEL_APPLE_TOUCHPAD, &isset));
-	ck_assert(isset == false);
+	litest_assert(quirks_get_bool(q, QUIRK_MODEL_APPLE_TOUCHPAD, &isset));
+	litest_assert(isset == false);
 
 	quirks_unref(q);
 	quirks_context_unref(ctx);
@@ -1416,7 +1457,7 @@ START_TEST(quirks_model_override)
 			   "ModelAppleTouchpad=%d\n",
 			   set ? 0 : 1,
 			   set ? 1 : 0);
-	ck_assert_int_ne(rc, -1);
+	litest_assert_int_ne(rc, -1);
 
 	dd = make_data_dir(quirks_file);
 
@@ -1425,13 +1466,13 @@ START_TEST(quirks_model_override)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 
 	q = quirks_fetch_for_device(ctx, ud);
-	ck_assert_notnull(q);
+	litest_assert_notnull(q);
 
-	ck_assert(quirks_get_bool(q, QUIRK_MODEL_APPLE_TOUCHPAD, &isset));
-	ck_assert(isset == set);
+	litest_assert(quirks_get_bool(q, QUIRK_MODEL_APPLE_TOUCHPAD, &isset));
+	litest_assert(isset == set);
 
 	quirks_unref(q);
 	quirks_context_unref(ctx);
@@ -1452,11 +1493,11 @@ START_TEST(quirks_model_alps)
 	exists = quirks_get_bool(q, QUIRK_MODEL_ALPS_SERIAL_TOUCHPAD, &value);
 
 	if (strstr(libinput_device_get_name(device), "ALPS")) {
-		ck_assert(exists);
-		ck_assert(value);
+		litest_assert(exists);
+		litest_assert(value);
 	} else {
-		ck_assert(!exists);
-		ck_assert(!value);
+		litest_assert(!exists);
+		litest_assert(!value);
 	}
 }
 END_TEST
@@ -1471,11 +1512,11 @@ START_TEST(quirks_model_wacom)
 	exists = quirks_get_bool(q, QUIRK_MODEL_WACOM_TOUCHPAD, &value);
 
 	if (libevdev_get_id_vendor(dev->evdev) == VENDOR_ID_WACOM) {
-		ck_assert(exists);
-		ck_assert(value);
+		litest_assert(exists);
+		litest_assert(value);
 	} else {
-		ck_assert(!exists);
-		ck_assert(!value);
+		litest_assert(!exists);
+		litest_assert(!value);
 	}
 }
 END_TEST
@@ -1490,11 +1531,11 @@ START_TEST(quirks_model_apple)
 	exists = quirks_get_bool(q, QUIRK_MODEL_APPLE_TOUCHPAD, &value);
 
 	if (libevdev_get_id_vendor(dev->evdev) == VENDOR_ID_APPLE) {
-		ck_assert(exists);
-		ck_assert(value);
+		litest_assert(exists);
+		litest_assert(value);
 	} else {
-		ck_assert(!exists);
-		ck_assert(!value);
+		litest_assert(!exists);
+		litest_assert(!value);
 	}
 }
 END_TEST
@@ -1510,26 +1551,26 @@ START_TEST(quirks_model_synaptics_serial)
 
 	if (libevdev_get_id_vendor(dev->evdev) == VENDOR_ID_SYNAPTICS_SERIAL &&
 	    libevdev_get_id_product(dev->evdev) == PRODUCT_ID_SYNAPTICS_SERIAL) {
-		ck_assert(exists);
-		ck_assert(value);
+		litest_assert(exists);
+		litest_assert(value);
 	} else {
-		ck_assert(!exists);
-		ck_assert(!value);
+		litest_assert(!exists);
+		litest_assert(!value);
 	}
 }
 END_TEST
 
 START_TEST(quirks_call_NULL)
 {
-	ck_assert(!quirks_fetch_for_device(NULL, NULL));
+	litest_assert(!quirks_fetch_for_device(NULL, NULL));
 
-	ck_assert(!quirks_get_uint32(NULL, 0, NULL));
-	ck_assert(!quirks_get_int32(NULL, 0, NULL));
-	ck_assert(!quirks_get_range(NULL, 0, NULL));
-	ck_assert(!quirks_get_dimensions(NULL, 0, NULL));
-	ck_assert(!quirks_get_double(NULL, 0, NULL));
-	ck_assert(!quirks_get_string(NULL, 0, NULL));
-	ck_assert(!quirks_get_bool(NULL, 0, NULL));
+	litest_assert(!quirks_get_uint32(NULL, 0, NULL));
+	litest_assert(!quirks_get_int32(NULL, 0, NULL));
+	litest_assert(!quirks_get_range(NULL, 0, NULL));
+	litest_assert(!quirks_get_dimensions(NULL, 0, NULL));
+	litest_assert(!quirks_get_double(NULL, 0, NULL));
+	litest_assert(!quirks_get_string(NULL, 0, NULL));
+	litest_assert(!quirks_get_bool(NULL, 0, NULL));
 }
 END_TEST
 
@@ -1547,7 +1588,7 @@ START_TEST(quirks_ctx_ref)
 				    log_handler,
 				    NULL,
 				    QLOG_CUSTOM_LOG_PRIORITIES);
-	ck_assert_notnull(ctx);
+	litest_assert_notnull(ctx);
 	ctx2 = quirks_context_ref(ctx);
 	litest_assert_ptr_eq(ctx, ctx2);
 	ctx2 = quirks_context_unref(ctx);
@@ -1590,6 +1631,7 @@ TEST_COLLECTION(quirks)
 	litest_add_deviceless(quirks_parse_vendor);
 	litest_add_deviceless(quirks_parse_vendor_invalid);
 	litest_add_deviceless(quirks_parse_product);
+	litest_add_deviceless(quirks_parse_product_too_many);
 	litest_add_deviceless(quirks_parse_product_invalid);
 	litest_add_deviceless(quirks_parse_version);
 	litest_add_deviceless(quirks_parse_version_invalid);
